OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Partajarea server-server nu este activată pe acest server",
    "Shared with you" : "Partajat cu tine",
    "Shared with others" : "Partajat cu alții",
    "Nothing shared with you yet" : "Nimic nu e partajat cu tine încă",
    "Nothing shared yet" : "Nimic partajat încă",
    "Cancel" : "Anulare",
    "Share" : "Partajează",
    "Shared by" : "impartite in ",
    "A file or folder has been <strong>shared</strong>" : "Un fișier sau director a fost <strong>partajat</strong>",
    "You shared %1$s with %2$s" : "Ai partajat %1$s cu %2$s",
    "You shared %1$s with group %2$s" : "Ai partajat %1$s cu grupul %2$s",
    "%2$s shared %1$s with you" : "%2$s a partajat %1$s cu tine",
    "You shared %1$s via link" : "Ai partajat %1$s prin legătură",
    "Shares" : "Partajări",
    "This share is password-protected" : "Această partajare este protejată cu parolă",
    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
    "Password" : "Parolă",
    "Name" : "Nume",
    "Reasons might be:" : "Motive posibile ar fi:",
    "the item was removed" : "acest articol a fost șters",
    "the link expired" : "linkul a expirat",
    "sharing is disabled" : "Partajare este oprită",
    "Add to your ownCloud" : "Adaugă propriul tău ownCloud",
    "Download" : "Descarcă",
    "Download %s" : "Descarcă %s"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
